==> haskell-hls-overloaded-record-dot-plugin-2.1.0.0-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-overloaded-record-dot-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-overloaded-record-dot-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-overloaded-record-dot-plugin-2.1.0.0-58gfp5ipqbDbsngxyQLLT

key:
    hls-overloaded-record-dot-plugin-2.1.0.0-58gfp5ipqbDbsngxyQLLT

license:              BSD-3-Clause
maintainer:           joyfulmantis@gmail.com
author:               Nathan Maxson
synopsis:             Overloaded record dot plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  bcf89c40350277be8942f58ff67f5af0
exposed:              True
exposed-modules:      Ide.Plugin.OverloadedRecordDot
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-overloaded-record-dot-plugin
hs-libraries:
    HShls-overloaded-record-dot-plugin-2.1.0.0-58gfp5ipqbDbsngxyQLLT

depends:
    aeson-2.1.2.1-6FuMYI3vdPa8Ts5NPsnpCg base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-7mveeBu1NdO3tDaPLTwSr0
    hls-graph-2.1.0.0-E0uwKa062XbErlHzLpQDMc
    hls-plugin-api-2.1.0.0-2mMBQBjk997A47exxFPkZd
    lens-5.3.1-57CGCDOUfQCLkJSlnZcVUR
    lsp-2.1.0.0-GxokUjVxBLy4j05JlhgdFg syb-0.7.3-Lap6GPARkRXCVbqA2faY6P
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-89DcpQLd7HI30AdGz5XyJk

haddock-interfaces:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html/hls-overloaded-record-dot-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-overloaded-record-dot-plugin-2.1.0.0-94-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-overloaded-record-dot-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-overloaded-record-dot-plugin
version:              2.1.0.0
visibility:           public
id:
    hls-overloaded-record-dot-plugin-2.1.0.0-BXwcfmnoq7BIoXpkvtWFFb

key:
    hls-overloaded-record-dot-plugin-2.1.0.0-BXwcfmnoq7BIoXpkvtWFFb

license:              BSD-3-Clause
maintainer:           joyfulmantis@gmail.com
author:               Nathan Maxson
synopsis:             Overloaded record dot plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  1c815573ca2fe939f3841897fbc9519c
exposed:              True
exposed-modules:      Ide.Plugin.OverloadedRecordDot
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-overloaded-record-dot-plugin-2.1.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-overloaded-record-dot-plugin
hs-libraries:
    HShls-overloaded-record-dot-plugin-2.1.0.0-BXwcfmnoq7BIoXpkvtWFFb

depends:
    aeson-2.1.2.1-3HLieqpkeG06w6MDAYdLLk base-4.17.2.1 containers-0.6.7
    deepseq-1.4.8.0 ghc-boot-th-9.4.8
    ghcide-2.1.0.0-EGobQkKgR8zaeADYgxOC5
    hls-graph-2.1.0.0-7LnpvrkjhrNH9iznMLZXCG
    hls-plugin-api-2.1.0.0-EfBvd6pBF3is65S9wzuFu
    lens-5.3.3-1zYcQilqoBK5EhYwkXjOnb
    lsp-2.1.0.0-4wEItkatDyfAFCzTPH6SAN syb-0.7.3-C5AaeelSWDKGvBUWTjIxkt
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20.1-JRJBW0Nl9iEJULI134IWXM

haddock-interfaces:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html/hls-overloaded-record-dot-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-overloaded-record-dot-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
